/**  @file inifile.c

     Read INI file for application.

     Copyright(C) 2007 Douglas Beattie Jr

     Author: Douglas Beattie Jr
     Created: DBJR 12/31/2007 7:22:34 PM
	Last change: DBJR 1/1/2008 12:35:26 PM
*/
/* $Log: C:\qVCS\Archives\util\zds2_Launcher\inifile.d $
 * 
 *   inifile.c
 * 
 * Revision 1.0  by: Douglas Beattie Jr.  Rev date: 1/1/2008 1:13:48 PM
 *   Initial Revision
 * 
 * $Endlog$
 */

#include <stddef.h>
#include <stdio.h>
#include <string.h>
#include "inifile.h"

char ez80_cmdline[RHSTRING_LENGTH] = "\0";
char z8f_cmdline[RHSTRING_LENGTH] = "\0";
char z16f_cmdline[RHSTRING_LENGTH] = "\0";

static char inpbuf[INPBUFFER_LENGTH];
static char lh_string[LHSTRING_LENGTH]; //Left-hand string
//static char rh_string[RHSTRING_LENGTH]; //Right-hand string
static char *rh_sptr = NULL;

static int read_ini_file(char *arg0_path);


int inifile_main(char *arg0_path)  //USE 'MAIN()' FOR INITIAL TEST
{
#ifndef NDEBUG
     printf("inifile_main() ... \n");
#endif
     if (read_ini_file(arg0_path) == 0) {
#ifndef NDEBUG
          printf(" ************ INI File Summary:\n");

          if(strlen(ez80_cmdline)) {
               printf("eZ80 Tool Path: '%s'\n", ez80_cmdline);
          }
          if(strlen(z8f_cmdline)) {
               printf("Z8F Tool Path: '%s'\n", z8f_cmdline);
          }
          if(strlen(z16f_cmdline)) {
               printf("Z16F Tool Path: '%s'\n", z16f_cmdline);
          }

          printf(" ******************************\n");
#endif
          return 0;
     }
     else {
          fprintf(stderr,"Can't Read INI File.\n");
     }

     return -1;
}

int read_ini_file(char *arg0_path)
{    // Read the INI file, FOR EXAMPLE
     //   ZDS_PATH_EZ80 = "C:\\Program Files\\ZiLOG\\ZDSII_eZ80Acc ...
     // ..and ignore lines beginning with '#'

     int line_count;
     FILE *fp;
     char *sptr;

     strcat(arg0_path,INI_FILE_NAME);
     fp = fopen(arg0_path, "r");

     if (fp != NULL) {

#ifndef NDEBUG
          printf("File %s opened\n", INI_FILE_NAME);
#endif
          line_count=0;

          do {
               if (fgets(inpbuf,INPBUFFER_LENGTH,fp) != NULL) {
                   line_count++;
                   //printf("\n........... %s",inpbuf);

                   // PROCESS THE LINE ...
                   //  - if a comment, skip it
                    if ( *inpbuf == '#' ) {
//                         printf("( COMMENT )\n");
                         continue;
                    }

                   //  - if string length >= 255, drop it.
                    if ( strlen(inpbuf) > 255 ) {
                         fprintf(stderr,"Line too long (#%d) in INI File\n",
                              line_count);
                         continue;
                    }

                    if (sscanf(inpbuf, "ZDS_PATH_%s = ", lh_string /*, rh_string*/)
                         != 1) {
                         fprintf(stderr,"bad line (#%d) in INI File\n", line_count);
                         continue;
                    }
                    else {
                         rh_sptr = strstr(inpbuf," = ");
                         if  (rh_sptr == NULL) {
                              continue;
                         }
                         // set right-hand string pointer
                         rh_sptr += /*(char *)*/ (3* sizeof(char));
                         // knock out any control chars, incl. CR/LF
                         sptr = rh_sptr + strlen(rh_sptr);
                         while (sptr > rh_sptr ) {
                              if ( *sptr < ' ' ) {
                                   *sptr = '\0';
                              }
                              --sptr;
                         }

                    }

                    if ( strcmp(lh_string, "EZ80")==0) {
                         strcpy(ez80_cmdline, rh_sptr); //rh_string);
                         continue;
                    }
                    if ( strcmp(lh_string, "Z8F")==0) {
                         strcpy(z8f_cmdline, rh_sptr); //rh_string);
                         continue;
                    }
                    if ( strcmp(lh_string, "Z16F")==0) {
                         strcpy(z16f_cmdline, rh_sptr); //rh_string);
                         continue;
                    }


               }

          } while (!feof(fp));

          fclose(fp);

#ifndef NDEBUG
          printf("%d lines processed.\n", line_count);
#endif
          return 0;
     }
     else {
          fprintf(stderr,"INI File %s Not Found!\n", INI_FILE_NAME);
          return 1;
     }
}

